DurationNanos

Struct DurationNanos 

pub struct DurationNanos(/* private fields */);
Represents an unsigned duration in nanoseconds.

Implementations

Source

impl DurationNanos

pub const ZERO: Self

A duration of zero nanoseconds.

pub const MAX: Self

The maximum duration representable by this type.

pub const fn new(nanos: u64) -> Self

Creates a duration from an exact nanosecond count.

pub const fn from_micros(micros: u64) -> Self

Creates a duration from a number of whole microseconds.

Panics

Panics if the result exceeds DurationNanos::MAX.

pub const fn try_from_micros( micros: u64, ) -> Result<Self, DurationNanosOutOfRangeError>

Creates a duration from a number of whole microseconds.

Errors

Returns an error if the result exceeds DurationNanos::MAX.

pub const fn from_millis(millis: u64) -> Self

Creates a duration from a number of whole milliseconds.

Panics

Panics if the result exceeds DurationNanos::MAX.

pub const fn try_from_millis( millis: u64, ) -> Result<Self, DurationNanosOutOfRangeError>

Creates a duration from a number of whole milliseconds.

Errors

Returns an error if the result exceeds DurationNanos::MAX.

pub const fn from_secs(secs: u64) -> Self

Creates a duration from a number of whole seconds.

Panics

Panics if the result exceeds DurationNanos::MAX.

pub const fn try_from_secs( secs: u64, ) -> Result<Self, DurationNanosOutOfRangeError>

Creates a duration from a number of whole seconds.

Errors

Returns an error if the result exceeds DurationNanos::MAX.

pub const fn from_mins(mins: u64) -> Self

Creates a duration from a number of whole minutes.

Panics

Panics if the result exceeds DurationNanos::MAX.

pub const fn try_from_mins( mins: u64, ) -> Result<Self, DurationNanosOutOfRangeError>

Creates a duration from a number of whole minutes.

Errors

Returns an error if the result exceeds DurationNanos::MAX.

pub const fn from_hours(hours: u64) -> Self

Creates a duration from a number of whole hours.

Panics

Panics if the result exceeds DurationNanos::MAX.

pub const fn try_from_hours( hours: u64, ) -> Result<Self, DurationNanosOutOfRangeError>

Creates a duration from a number of whole hours.

Errors

Returns an error if the result exceeds DurationNanos::MAX.

pub const fn from_days(days: u64) -> Self

Creates a duration from a number of whole days.

Panics

Panics if the result exceeds DurationNanos::MAX.

pub const fn try_from_days( days: u64, ) -> Result<Self, DurationNanosOutOfRangeError>

Creates a duration from a number of whole days.

Errors

Returns an error if the result exceeds DurationNanos::MAX.

pub const fn is_zero(&self) -> bool

Returns true if the duration is zero.

pub const fn as_u64(&self) -> u64

Returns the exact duration in nanoseconds as u64.

pub const fn as_micros(&self) -> u64

Returns the total duration in whole microseconds.

pub const fn as_millis(&self) -> u64

Returns the total duration in whole milliseconds.

pub const fn as_secs(&self) -> u64

Returns the total duration in whole seconds.

pub const fn as_secs_f64(&self) -> f64

Returns the total duration in seconds as f64.

pub const fn as_mins(&self) -> u64

Returns the total duration in whole minutes.

pub const fn as_hours(&self) -> u64

Returns the total duration in whole hours.

pub const fn as_days(&self) -> u64

Returns the total duration in whole 24-hour days.

pub const fn subsec_millis(&self) -> u64

Returns the fractional part of this duration in whole milliseconds.

pub const fn subsec_micros(&self) -> u64

Returns the fractional part of this duration in whole microseconds.

pub const fn subsec_nanos(&self) -> u64

Returns the fractional part of this duration in nanoseconds.

pub const fn checked_add(self, rhs: Self) -> Option<Self>

Returns Some(self + rhs) or None if the addition would overflow.

pub const fn checked_sub(self, rhs: Self) -> Option<Self>

Returns Some(self - rhs) or None if the subtraction would underflow.

pub const fn saturating_add(self, rhs: Self) -> Self

Adds rhs, saturating at DurationNanos::MAX.

pub const fn saturating_sub(self, rhs: Self) -> Self

Subtracts rhs, saturating at zero.

pub const fn checked_mul(self, rhs: u64) -> Option<Self>

Returns Some(self * rhs) or None if the multiplication would overflow.

pub const fn saturating_mul(self, rhs: u64) -> Self

Multiplies by rhs, saturating at DurationNanos::MAX.

pub const fn checked_div(self, rhs: u64) -> Option<Self>

Returns Some(self / rhs) or None if rhs is zero.